@@ -698,11 +698,11 @@ Chain Chain::truncRight(const Chain& str) const
     {
 	unsigned long i, u;
 
-	u=_len-1;
+	u=_len;
 	i=0;
-	while (i < str._len && u >= 0)
+	while (i < str._len && u > 0)
 	{	    
-	    if (_buf[u] == str._buf[i])
+	    if (_buf[u-1] == str._buf[i])
 	    {	
 		u--;
 		i=0;
@@ -713,8 +713,8 @@ Chain Chain::truncRight(const Chain& str) const
 	    }
 	}
 
-	if ( u >= 0 )
-	    return subChain(1, u+1);
+	if ( u > 0 )
+	    return subChain(1, u);
 	else
 	    return Chain("");
     }
