@@ -29,10 +29,12 @@ class Matcher {
 
 public:
     
-    Matcher(const Chain& exp);
+    Matcher(const Chain& exp = Chain());
     ~Matcher();
+
+    void setExpr(const Chain& expr);
+    const Chain& getExpr() const;
     
-    Chain getExpr() const;
     void prepare(bool isExtended = true);
 
     bool match(const Chain& str);
