@@ -610,10 +610,10 @@ Chain getSourceInfo(struct sockaddr *s)
     */
     
     char ip[INET6_ADDRSTRLEN];
-    uint16_t port;
+    // uint16_t port;
 
     void *addr;
-    char *ipver;
+    // char *ipver;
     
     if (sin->sin_family == AF_INET)	
     {
