@@ -636,7 +636,7 @@ void Pager::managePager()
     _cols = COLS;
 
     
-    int i, ch = 0; 
+    int ch = 0; 
     
     do 
     { 	
@@ -881,7 +881,7 @@ void Pager::writeHeader()
 	int len;
         getAttrSpec(colPos, *pAttr, attr, len); 
 
-	if (  col + attr.length() < _cols )
+	if (  col + (int)attr.length() < _cols )
 	    mvprintw(0, col, "%s", (char*)attr); 
 
 	colPos++;
@@ -929,7 +929,7 @@ void Pager::writePage()
 	    getAttrSpec(colPos, *pAttr, attr, len); 
 	    
 	    Chain val = _outData[i+_vStart][colPos];
-	    if ( val != Chain()  && col + val.length() < _cols )
+	    if ( val != Chain()  && col + (int)val.length() < _cols )
 		mvprintw(i + HEADERSIZE, col, "%s", (char*)val); 
 	    col += len;
 	    colPos++;
@@ -1080,12 +1080,12 @@ void Pager::refreshRow(int dataRow, int pageRow)
 		    
 	if ( 1 ) // perhaps later we also make right align : lenInfo[0] == 'l' )
 	{
-	    if ( *pVal && colno + pVal->length() < _cols )
+	    if ( *pVal && colno + (int)pVal->length() < _cols )
 		mvwprintw(stdscr, pageRow, colno, "%s", (char*)*pVal);
 	}
 	else
 	{
-	    int offset = len - pVal->length();
+	    int offset = len - (int)pVal->length();
 	    if ( *pVal )
 		mvwprintw(stdscr, pageRow, colno+offset, "%s", (char*)*pVal);	    
 	}
@@ -1127,8 +1127,8 @@ void Pager::formatData(const ListT< ListT<Chain> > & outData)
     _rowHeight.Empty();
     
     ListT<Chain> *pRow = outData.First();
+
     
-    int rowNo=0;
     while ( pRow )
     {
 	int lineNo=0;
@@ -1160,8 +1160,8 @@ void Pager::formatData(const ListT< ListT<Chain> > & outData)
 		    // cout << "Got token " << s << " for lineno = " << lineNo << endl;
 		    outRow.Insert(s);
 
-		    if ( _outLen[colNum] < s.length() + 1 )
-			_outLen[colNum] = s.length() + 1;
+		    if ( _outLen[colNum] < (int)s.length() + 1 )
+			_outLen[colNum] = (int)s.length() + 1;
 		    
 		    moreLines=true;
 		}
@@ -1179,7 +1179,6 @@ void Pager::formatData(const ListT< ListT<Chain> > & outData)
 	    {
 		_outData.Insert(outRow);
 		lineNo++;
-		rowNo++;
 	    }
 	}
 
@@ -1280,11 +1279,11 @@ void Pager::setCommand(const Chain& cmd)
     
     int i=0;
     int row=0;
-    while ( row < MAXCMDROW && i < cmd.length() )
+    while ( row < MAXCMDROW && i < (int)cmd.length() )
     {
 	int col=0;
 	bool eol=false;
-	while (  i < cmd.length() && ! eol ) 
+	while (  i < (int)cmd.length() && ! eol ) 
 	{	    
 	    if ( cmd[i] != '\n' )
 	    {
@@ -1364,7 +1363,7 @@ void Pager::showHelp(int helpMode)
 	mvwprintw(helpwin, i++, 2, "%s",  (char*)"Cntrl-t    - Terminate");
     }
     
-    int c = wgetch(helpwin);
+    wgetch(helpwin);
 
     wrefresh(helpwin);
     
@@ -1382,16 +1381,14 @@ void Pager::showMessage()
     
     curs_set(0);
     
-    int startx, starty;
-
     int xoff,yoff;
     getbegyx(stdscr, yoff, xoff);
     
     int x,y;
     getmaxyx(stdscr, y, x);
 
-    startx = xoff + (x / 7);
-    starty = yoff + (y / 4);
+    // startx = xoff + (x / 7);
+    int starty = yoff + (y / 4);
 
     Tokenizer tok(_msg, Chain("\n"));
     Chain token;
@@ -1399,8 +1396,8 @@ void Pager::showMessage()
     int rows = 3;
     while (tok.nextToken(token) == true)
     {	    
-	if ( token.length() + 4 > cols )
-	    cols = token.length() + 4;
+	if ( (int)token.length() + 4 > cols )
+	    cols = (int)token.length() + 4;
 	rows++;
     }
     
@@ -1423,7 +1420,7 @@ void Pager::showMessage()
         
     refresh();
 
-    int c = wgetch(msgwin);
+    wgetch(msgwin);
 
     wclear(msgwin);
     delwin(msgwin);
@@ -1438,7 +1435,7 @@ bool Pager::showSearch()
 
     curs_set(1);
     
-    int startx, starty;
+    // int startx, starty;
 
     
     int xoff,yoff;
@@ -1447,8 +1444,8 @@ bool Pager::showSearch()
     int x,y;
     getmaxyx(stdscr, y, x);
 
-    startx = xoff + (x / 7);
-    starty = yoff + (y / 4);
+    // startx = xoff + (x / 7);
+    int starty = yoff + (y / 4);
 
     
     WINDOW* searchwin = newwin( 4, MAXSEARCHLEN + 3, starty, 2);
