@@ -313,7 +313,7 @@ void Screen::showInfoBox(const Chain& title, const Chain& msg, int width)
     int lno=3;
     while ( t.nextToken(l))
     {
-	if ( l.length() + 4 > width )
+	if ( (int)l.length() + 4 > width )
 	    l = l.subChain(1, width - 4);
 	mvwprintw(infowin, lno, 2, "%s", (char*)l);
 	lno++;
@@ -346,16 +346,13 @@ int Screen::showConfirmBox(const Chain& title, const Chain& details, int posx, i
     
     int width = max(title.length(), details.length()) + 5; 
     int height = 7;
-    
-    int confVal = 0;
-    
+        
     bool showIt=true;
 
     WINDOW* confwin = 0;
 
     int curRow = 5; 
     int curCol = OK_COL_POS; 
-    int isFirst = 1;
     
     while( showIt )
     {
@@ -470,7 +467,7 @@ int Screen::showSelectBox(const Chain& title, const ListT<Chain>& selectList,
     Chain *pS = selectList.First();
     while ( pS )
     {
-	width = pS->length() + 1 > width ? pS->length() + 1 : width;   
+	width = (int)pS->length() + 1 > width ? (int)pS->length() + 1 : width;   
 	pS = selectList.Next();
     }
     int height = selectList.Size() + 4;
@@ -647,9 +644,9 @@ int Screen::showFormBox(const Chain& title, const ListT<Chain>& attrList, ListT<
 		}
 	    }
 	    
-            for(int j = 0; j < value.length(); j++)
+            for(int j = 0; j < (int)value.length(); j++)
                 inputArray[i][j]=value[j];
-            for(int j = value.length(); j < VAL_MAX_LEN; j++)
+            for(int j = (int)value.length(); j < VAL_MAX_LEN; j++)
                 inputArray[i][j]=0;
 	}
 	else
@@ -657,10 +654,10 @@ int Screen::showFormBox(const Chain& title, const ListT<Chain>& attrList, ListT<
 	    inputArray[i][0]=0;
 	}
 
-	if ( colOffset < attr.length() )
+	if ( colOffset < (int)attr.length() )
 	    colOffset = attr.length();
 	
-	if ( width < maxVisible + attr.length() )
+	if ( width < maxVisible + (int)attr.length() )
 	    width = maxVisible + attr.length();
     }
     
@@ -734,7 +731,7 @@ int Screen::showFormBox(const Chain& title, const ListT<Chain>& attrList, ListT<
 		wcolor_set(maskwin, COL_INPUT, NULL);
 		for(int j = 0; j < min(maxLen,maxVisible); ++j)
 		    mvwprintw(maskwin, y, colOffset + j, " ");
-		if ( inputArray[i] )
+		if ( inputArray[i][0] )
 		{
 		    if ( type == Chain(INPUT_TYPE_PWD) )
 		    {
@@ -884,9 +881,9 @@ int Screen::showFormBox(const Chain& title, const ListT<Chain>& attrList, ListT<
 		    {
 			if ( (char*)selectKey )
 			{
-			    for(int j = 0; j < selectKey.length(); j++)
+			    for(int j = 0; j < (int)selectKey.length(); j++)
 				inputArray[curRow-CUR_ROW_OFFSET][j]=selectKey[j];
-			    for(int j = selectKey.length(); j < VAL_MAX_LEN; j++)
+			    for(int j = (int)selectKey.length(); j < VAL_MAX_LEN; j++)
 				inputArray[curRow-CUR_ROW_OFFSET][j]=0;
 			}
 			else
@@ -1694,10 +1691,3 @@ int Screen::getHeight()
     return height;
 }
 
-int Screen::getWidth()
-{
-    int height, width;   
-    getmaxyx(stdscr, height, width);
-    return width;
-}
-
