@@ -208,8 +208,8 @@ void Screen2::Message::setInfo(const Chain& title, const Chain& msg, int height)
     {
 	if ( height == 0 )
 	    _height++;
-	if ( l.length() > _width )
-	    _width = l.length();
+	if ( (int)l.length() > _width )
+	    _width = (int)l.length();
 	_msgHeight++;
     }
     
@@ -321,7 +321,7 @@ void Screen2::Select::setItems( const Chain& title, const ListT<Chain>& items)
     {
 	Chain key, value;
 	getKeyValue(*pS, key, value);
-	_width = key.length() + 3 > _width ? key.length() + 3 : _width;   
+	_width = (int)key.length() + 3 > _width ? key.length() + 3 : _width;   
 	pS = _items.Next();
     }
     
@@ -537,8 +537,8 @@ void Screen2::Grid::handleKey(int c)
     }
     case KEY_ESC:
     {
-      if ( _gridwin != 0 )
-	delwin(_gridwin);
+	if ( _gridwin != 0 )
+	    delwin(_gridwin);
 	_gridwin=0;
 	_pNext = _pParent;
 	return;
@@ -956,9 +956,9 @@ void Screen2::Form::setAttrList(const Chain& title, const ListT<Chain>& attrList
 		}
 	    }
 	    
-            for(int j = 0; j < value.length(); j++)
+            for(int j = 0; j < (int)value.length(); j++)
                 _inputArray[i][j]=value[j];
-            for(int j = value.length(); j < VAL_MAX_LEN; j++)
+            for(int j = (int)value.length(); j < VAL_MAX_LEN; j++)
                 _inputArray[i][j]=0;
 	}
 	else
@@ -966,10 +966,10 @@ void Screen2::Form::setAttrList(const Chain& title, const ListT<Chain>& attrList
 	    _inputArray[i][0]=0;
 	}
 
-	if ( _colOffset < attr.length() )
+	if ( _colOffset < (int)attr.length() )
 	    _colOffset = attr.length();
 	
-	if ( _width < _maxVisible + attr.length() )
+	if ( _width < _maxVisible + (int)attr.length() )
 	    _width = _maxVisible + attr.length();
     }
     
@@ -1003,9 +1003,9 @@ void Screen2::Form::setValueList(const ListT<Chain>& valList)
 		getListKey(defValue, value, menuKey);
 		value = menuKey;
 	    }
-            for(int j = 0; j < value.length(); j++)
+            for(int j = 0; j < (int)value.length(); j++)
                 _inputArray[i][j]=value[j];
-            for(int j = value.length(); j < VAL_MAX_LEN; j++)
+            for(int j = (int)value.length(); j < VAL_MAX_LEN; j++)
                 _inputArray[i][j]=0;
 	}
 	else
@@ -1034,7 +1034,7 @@ void Screen2::Form::clear()
 		Tokenizer t2(menuItem, VALSEPTOKEN);	      
 		t2.nextToken(menuKey);	
 	    }	   
-	    for(int j = 0; j < menuKey.length(); j++)
+	    for(int j = 0; j < (int)menuKey.length(); j++)
 		_inputArray[i][j]=menuKey[j];	    
 	}
 	else
@@ -1102,7 +1102,7 @@ void Screen2::Form::show(bool doRec)
 	    wcolor_set(_formwin, COL_INPUT, NULL);
 	    for(int j = 0; j < min(maxLen, _maxVisible); ++j)
 		mvwprintw(_formwin, y, _colOffset + j, " ");
-	    if ( _inputArray[i] )
+	    if ( _inputArray[i][0] )
 	    {
 		if ( type == Chain(INPUT_TYPE_PWD) )
 		{
@@ -1560,9 +1560,9 @@ Screen2::Panel* Screen2::Form::FormSelect::onSelect(int selected)
     Chain key, value;
     getKeyValue(item, key, value);
     
-    for(int j = 0; j < key.length(); j++)
+    for(int j = 0; j < (int)key.length(); j++)
 	_pInput[j]=key[j];
-    for(int j = key.length(); j < VAL_MAX_LEN; j++)
+    for(int j = (int)key.length(); j < VAL_MAX_LEN; j++)
 	_pInput[j]=0;
     
     return _pParent;
@@ -1640,9 +1640,9 @@ void Screen2::Attribute::show(bool doRec)
 		t.nextToken(key);
 		t.nextToken(value);
 		
-		if ( key.length() > maxKeyLen )
+		if ( (int)key.length() > maxKeyLen )
 		    maxKeyLen = key.length();
-		if ( value.length() > maxValLen )
+		if ( (int)value.length() > maxValLen )
 		    maxValLen = value.length();
 		pKV = pKVL->Next();
 	    }
@@ -1679,9 +1679,9 @@ WINDOW* Screen2::Attribute::createWindow(int xpos, int ypos, const Chain& title,
 	t.nextToken(key);
 	t.nextToken(value);
 	
-	if ( key.length() > maxKeyLen )
+	if ( (int)key.length() > maxKeyLen )
 	    maxKeyLen = key.length();
-	if ( value.length() > maxValLen )
+	if ( (int)value.length() > maxValLen )
 	    maxValLen = value.length();
 	pKV = pAttrList->Next();
     }
@@ -1906,7 +1906,7 @@ void Screen2::showScreen()
 	doEnter=false;      
 	doRec=false;
 	
-	int colno=LEFTOFFSET; 
+	// int colno=LEFTOFFSET; 
 	attroff(A_REVERSE); 
 	
 	WINDOW* pWin = _pPanel->getWindow();
